@@ -19,15 +19,13 @@ from framework.serializer import BaseModelSerializer, EditParams, IdSerializer,
 from framework.views import CurdViewSet, HttpResponse, notauth, render, render_to_response
 from log_def.models import DictDefine
 
-
-
 from framework.settings import settings
-from framework.utils import json_dumps, md5, trace_msg,ObjectDict
+from framework.utils import json_dumps, md5, trace_msg, ObjectDict
 from addict import Dict
 from framework.utils.cache import cache_func, CACHE_TYPE, clear_cache
 from .exprot_file import QueryExprot
-
-from ..models.query import Query, QueryAnalysis
+import logging
+from ..models.query import Query, QueryCompiler, SqlMarkManager
 
 filterwarnings('ignore', category=MySQLdb.Warning)
 
@@ -41,7 +39,7 @@ class QuerySerializer(BaseModelSerializer):
         model = Query
         fields = ['id', 'log_key', 'log_type', 'field_config', 'key', 'name', 'select', 'where', 'group', 'order',
                   'order_type', 'sql', 'other_sql', 'cache_validate', 'remark', 'template_name', 'create_datetime',
-                  'update_datetime', 'order_type_alias'] or '__all__'
+                  'update_datetime', 'order_type_alias', 'is_paging'] or '__all__'
         # exclude = ['session_key']
         read_only_fields = ['create_datetime', 'update_datetime']
         extra_kwargs = {'password': {'write_only': True}}
@@ -73,13 +71,14 @@ class QuerySet(CurdViewSet):
     @swagger_auto_schema(query_serializer=MyFilterSerializer, responses=ListQueryRspSerializer)
     def list(self, request, ):
         """查询 列表"""
-        return render_to_response('analysis/query/list.html',super().list(request))
+        return render_to_response('analysis/query/list.html', super().list(request))
 
     @swagger_auto_schema(query_serializer=EditParams, responses=QuerySerializer)
     def edit(self, request, *args, **kwargs):
         """查询 编辑"""
-
-        return render_to_response('analysis/query/edit.html', super().edit(request))
+        data = super().edit(request).data.data
+        data.update({'mark_map': SqlMarkManager.mark_map})
+        return render_to_response('analysis/query/edit.html', data)
 
     @swagger_auto_schema(query_serializer=IdSerializer, request_body=QuerySerializer, responses=QuerySerializer)
     def save(self, request, *args, **kwargs):
@@ -111,8 +110,8 @@ def get_field_id_for_dict(field_dict, value):
 @Route('analysis/query/interface/(\S+)$')
 @notauth
 def interface(request, query_name, template='query_csv'):
-    '''查询接口
-    '''
+    """查询接口
+    """
     if not hasattr(request, 'admin'):
         pass
 
@@ -123,16 +122,17 @@ def interface(request, query_name, template='query_csv'):
 def query_widget(request, query_name):
     return query_view(request, query_name=query_name, is_query_do=False, template='query/query_widget.html')
 
+
 @Route('query/view$')
 @Route('query/view/(\S+)$')
 @Route('analysis/query/view$')
 @Route('analysis/query/view/(\S+)$')
 def query_view(request, query_name='', query_model=None, is_query_do=False, list_data_handle=False,
                template='analysis/query_view.html'):
-    '''查询视图,request 传入
+    """查询视图,request 传入
     @param query_name:查询名称
     @param is_query_do: 是否执行查询
-    '''
+    """
 
     now = datetime.datetime.now()
     _g = request.REQUEST.get
@@ -156,14 +156,14 @@ def query_view(request, query_name='', query_model=None, is_query_do=False, list
     # print params
     params = Dict(params)
     log_def = the_query.log_def
-    query_analysis = QueryAnalysis(the_query, params)
+    query_compiler = QueryCompiler(the_query, params)
     is_center_query = the_query.is_center_query
     is_export = _g('is_export', 'False') == 'true'
 
     if is_export:  # 导出
-        return query_export_do(request, query_analysis)
+        return query_export_do(request, query_compiler)
     if is_query_do or request.method == 'POST' or request.REQUEST.get('query_do') or request.GET.get('template', ''):
-        return query_do(request, query_analysis, list_data_handle=list_data_handle)
+        return query_do(request, query_compiler, list_data_handle=list_data_handle)
 
     same_log_key_query_list = Query.objects.filter(
             log_key=the_query.log_key)  # 查询的表定义
@@ -191,21 +191,21 @@ def query_view(request, query_name='', query_model=None, is_query_do=False, list
 
     conditions_configs.sort(key=lambda x: x[2])
 
-    mark_conditions = query_analysis.generate_mark_conditions()
+    mark_conditions = query_compiler.generate_mark_conditions()
 
     sdate = request.REQUEST.get('sdate', '') or (
             now + datetime.timedelta(-6)).strftime('%Y-%m-%d 00:00:00')
     edate = request.REQUEST.get(
             'edate', '') or now.strftime('%Y-%m-%d 23:59:59')
 
-    has_sdate = query_analysis.has_mark('sdate')
-    has_edate = query_analysis.has_mark('edate')
+    has_sdate = query_compiler.has_mark('sdate')
+    has_edate = query_compiler.has_mark('edate')
 
     # 如果没有查询区间，默认查询当天的数据
     if mark_conditions['sdate'] and not mark_conditions['edate']:
         sdate = request.REQUEST.get('sdate', '') or now.strftime('%Y-%m-%d 00:00:00')
 
-    has_other_conditions = query_analysis.has_conditions()
+    has_other_conditions = query_compiler.has_conditions()
 
     has_conditions = False
     for v in mark_conditions.values():
@@ -216,7 +216,7 @@ def query_view(request, query_name='', query_model=None, is_query_do=False, list
     has_conditions = has_conditions or has_other_conditions
 
     if request.user.is_agent and not mark_conditions['channel']:
-        return render(request,'framework/block.html', {"err_msg": "'此查询非法!'"})
+        return render(request, 'framework/block.html', {"err_msg": "'此查询非法!'"})
 
     plugin_templates = []
     if the_query.template_name:
@@ -228,13 +228,14 @@ def query_view(request, query_name='', query_model=None, is_query_do=False, list
                         template_path)
 
     server_id = request.REQUEST.get('server_id', 0)
-
-    return render(request,template, locals())
+    from ..views.widgets import get_query_servers
+    query_servers = get_query_servers(request)
+    return render(request, template, locals())
 
 
-def query_export_do(request, query_analysis):
-    '''查询导出文件
-    '''
+def query_export_do(request, query_compiler: QueryCompiler):
+    """查询导出文件
+    """
 
     _g = request.REQUEST.get
     _gl = request.REQUEST.getlist
@@ -248,7 +249,7 @@ def query_export_do(request, query_analysis):
     request.POST.setlist('page_size', [page_size])
     export_fields = _gl('export_fields')
 
-    fields = query_analysis.query.selects
+    fields = query_compiler.query.selects
     #  导出字段index
     export_indexs = [fields.index(i) for i in export_fields]
 
@@ -266,8 +267,8 @@ def query_export_do(request, query_analysis):
         return HttpResponseRedirect(new_url)
     else:
         total_record, list_data = query_do(
-                request, query_analysis, built_in=True)
-        export_file_name = '%s_%s' % (query_analysis.query.name, q_server_id)
+                request, query_compiler, built_in=True)
+        export_file_name = '%s_%s' % (query_compiler.query.name, q_server_id)
         _r = query_exprot.gene_file(
                 export_file_name, list_data, fields, export_indexs, page_num, page_size, total_record)
     _r["code"] = 0
@@ -275,17 +276,16 @@ def query_export_do(request, query_analysis):
     return HttpResponse(json_dumps(_r))
 
 
-def query_do(request, query_analysis, built_in=False, list_data_handle=None):
-    '''执行查询
-    '''
+def query_do(request, query_compiler: QueryCompiler, built_in=False, list_data_handle=None):
+    """执行查询
+    """
 
     template_name = request.REQUEST.get('template', '') or 'json'
     now = getattr(request, '_start_time', time.time())
     _g = request.REQUEST.get
     _gl = request.REQUEST.getlist
     err_msg = ''
-    server_id = request.REQUEST.get('server_id', '')
-    game_alias = request.REQUEST.get('game_alias', '')
+    server_id = int(request.REQUEST.get('server_id', '0'))
 
     total_record = total_page = 0
     page_num = int(_g('page_num', '') or 0) or 1  # 页码
@@ -297,217 +297,62 @@ def query_do(request, query_analysis, built_in=False, list_data_handle=None):
     tfoot_data = []
     query_sql = count_sql = ''
     try:
-        if not query_analysis.query.is_center_query:
-            server_conn_id = 0
-            if server_id :
-                server_conn_id = server_id
-            #     from ..models import Server
-            #     try:
-            #         if server_id.isdigit():
-            #             server_model = Server.objects.get(id=server_id)
-            #         elif game_alias:
-            #             server_model = Server.objects.get(alias=game_alias)
-            #             server_id = server_model.id
-            #         # 获取从库链接
-            #         conn = server_model.mysql_conn()
-            #         query_analysis.params.update(
-            #                 {"server_name": [server_model.name]})  # 传服务器名
-            #         query_analysis.params.update(
-            #                 {"game_alias": [server_model.alias]})  # 传游戏/服务器代号
-            #         master_id = server_model.master_server.id
-            #         query_analysis.params.update({"master_id":[master_id]})                          #传母服id
-            #         query_analysis.params.update({"master_db":[server_model.master_server.db_name]}) #传母服数据库名
-            #         query_analysis.params.update({"server_name":[server_model.name]})                #传服务器名
-            #     except Exception as e:
-            #
-            #         err_msg = '数据库链接出错! %s' % str(e)
-            # else:
-            #     err_msg = '没有服务器ID'
+        conn = query_compiler.get_conn(server_id)
+        # 设置输入参数
+        query_compiler.set_mark_parmas(request)
+        # 设置 limit 限制
+        query_compiler.set_limit(page_size, page_num)
+        # 替换变量，生成 sql
+        query_compiler.query_sql_handle()
+        fields = query_compiler.query.selects
+        # 设置排序
+        sort_type = _g('sort_type', '')
+        sort_fields_index = int(_g('sort_index', '') or -1)
+        if sort_fields_index >= 0 and len(fields) >= sort_fields_index:
+            sort_field_name = fields[sort_fields_index]
+            sort_key = query_compiler.query.field_config.get(
+                    sort_field_name, {}).get('name', '')
+            if sort_key and sort_type:
+                query_compiler.set_order(sort_key, sort_type)
 
-        conn = ServerConnect.get_conn(server_conn_id)
+        count_sql = query_compiler.get_count_sql()
+        query_sql = query_compiler.get_query_sql()
 
-        is_sdk_manager = 1 if request.user.is_sdk_manager else 0
-        is_manager = 1 if request.user.is_manager else 0
-        is_root = 1 if request.user.is_root or is_sdk_manager else 0
+        # 知道结果的数量情况下,添加_分页,不执行count设置分页
+        if not query_compiler.query.is_paging:
+            total_record = page_size
 
-        query_analysis.params['is_manager'] = [is_manager]
-        query_analysis.params['is_root'] = [is_root]
+        # 默认不打印sql
+        if settings.DEBUG or request.REQUEST.get('_sql', ''):
+            print(query_sql)
 
-        query_analysis.params['kouliang_rate'] = [1]
-        query_analysis.params['min_kouliang_num'] = [0]
+        cache_time = int(query_compiler.query.cache_validate)
+        count_sql_key = md5('%s_%s' % (count_sql, server_id))
+        cursor = conn.cursor()
+        if not total_record:
+            total_record, result_cache_time = cache_func(
+                    count_sql_key, get_query_result_cout, (conn, count_sql), timeout=cache_time)
 
-        if request.REQUEST.get('use_kouliang_test', 'false') == 'true':  # 扣量
-            query_analysis.params['kouliang_rate'] = [0.5]
-            query_analysis.params['min_kouliang_num'] = [0]
+        if total_record:
+            query_sql_key = md5('%s_%s' % (query_sql, server_id))
+            total_page = total_record / page_size
+            if total_record % page_size != 0:
+                total_page += 1
+            list_data, result_cache_time = cache_func(
+                    query_sql_key, get_query_result, (conn, query_sql), timeout=cache_time)
+            list_data, result_cache_time = cache_func('display_%s' % query_sql_key, query_display_process, (
+                    query_compiler, list_data, page_num, page_size), timeout=cache_time)
+            tfoot_sql = query_compiler.get_tfoot_sql()
 
-        # 限制渠道查询 不是root的都需要限制,渠道用户如果没有channel_ids标记则提示错误
-        if not request.user.is_root:
-            if query_analysis.has_mark('user_id'):
-                query_analysis.params['user_id'] = [request.user.id]
-
-            if query_analysis.has_mark(u"SDK"):
-                allow_sdk = request.user.get_resource("sdk_alias")
-                if len(allow_sdk) > 0:
-                    sdk_codes = [i.simpleName for i in allow_sdk]
-                    pname = query_analysis.query.field_config.get(
-                            u"SDK", {}).get("name", "")
-                    select_code = query_analysis.params.get(pname) or []
-                    select_code = list(
-                            set(select_code).intersection(set(sdk_codes)))
-                    query_analysis.params[pname] = select_code
-                    if not select_code:
-                        query_analysis.params[pname] = sdk_codes
-
-            if query_analysis.has_mark('platform_ids'):
-                # 获取请求参数 ,如果没有就用这个用户所有的权限
-                old_platform_ids = query_analysis.params.get('platform_id', [])
-                new_platform_ids = old_platform_ids or list(
-                        request.user.get_resource('platform').values_list('key', flat=True))
-                query_analysis.params['platform_id'] = new_platform_ids or [
-                        '-99']
-                # 如果是平台的查询就不需要限制服务器和渠道了
-            else:
-                if query_analysis.has_mark('server_ids'):
-                    old_server_ids = query_analysis.params.get('server_id', [])
-                    new_server_ids = request.user.get_resource_ids(
-                            'server', old_server_ids)
-                    new_server_ids = new_server_ids or [-99]
-                    new_server_ids.append(0)  # 激活数据服务器是0的
-                    query_analysis.params['server_id'] = new_server_ids
-
-                if query_analysis.has_mark('game_aliass'):
-                    old_servers = query_analysis.params.get('game_alias', [])
-                    new_servers = request.user.get_resource_attrs(
-                            'server', 'alias', old_servers)
-                    new_servers = new_servers or [-99]
-                    query_analysis.params['game_alias'] = new_servers
-
-                if query_analysis.has_mark('channels'):
-                    old_channels = query_analysis.params.get('channel', [])
-                    # 对于管理员，允许空渠道查询
-                    if not is_manager:
-                        allow_channel = request.user.get_resource_attrs('channel', 'key', old_channels,
-                                                                         allow_none=True)
-                        allow_agent = request.user.get_resource_attrs('agent', 'alias', old_channels, allow_none=True)
-                        allow_media = request.user.get_resource_attrs('media', 'account_id', old_channels,
-                                                                       allow_none=True)
-
-                        new_channels = (allow_agent + allow_channel + allow_media)
-                        # request.user.get_resource_attrs('channel','key',old_channels)
-                        if not new_channels and old_channels:
-                            err_msg = '没有允许你查询的渠道!'
-                        elif not new_channels:
-                            new_channels = ['']
-
-                        # new_channels += request.user.get_resource_attrs('agent','alias',old_channels)
-
-                        query_analysis.params['channel'] = new_channels or [-99]
-
-                elif query_analysis.has_mark('plan_channel'):
-                    old_channels = query_analysis.params.get('channel', [])
-                    # 对于管理员，允许空渠道查询
-                    if not is_manager:
-                        allow_agent = request.user.get_resource_attrs(
-                                'agent', 'alias', old_channels, allow_none=True)
-                        new_channels = allow_agent
-                        if not new_channels and old_channels:
-                            err_msg = '没有允许你查询的渠道!'
-                        elif not new_channels:
-                            new_channels = ['']
-                        query_analysis.params['channel'] = new_channels or [-99]
-
-                elif query_analysis.has_mark('first_channel'):
-                    old_channels = query_analysis.params.get('channel', [])
-                    # 对于管理员，允许空渠道查询
-                    if not is_manager:
-                        allow_agent = request.user.get_resource_attrs(
-                                'agent', 'alias', old_channels, allow_none=True)
-                        new_channels = allow_agent
-                        if not new_channels and old_channels:
-                            err_msg = '没有允许你查询的渠道!'
-                        elif not new_channels:
-                            new_channels = ['']
-                        query_analysis.params['channel'] = new_channels or [-99]
-
-
-
-                elif request.user.is_channel_user:
-                    err_msg = '此查询未包涵渠道过滤条件!'
-
-                if request.user.is_channel_user:
-                    if not query_analysis.has_mark('kouliang_rate') or not query_analysis.has_mark('min_kouliang_num'):
-                        err_msg = '查询还未处理完成- -!'
-                    else:
-                        query_analysis.params['kouliang_rate'] = [
-                                request.user.distribution_packet_plan.kouliang_rate]
-                        query_analysis.params['min_kouliang_num'] = [
-                                request.user.distribution_packet_plan.min_kouliang_num]
-
-        # 空渠道号
-        if is_manager and query_analysis.params.get('channel') and request.REQUEST.get('is_empty_channel',
-                                                                                       'false') == 'true':
-            query_analysis.params['channel'].append('')
-
-        # 运营分析不限制渠道条件
-        if request.user.is_yunying and query_analysis.params.get('channel'):
-            query_analysis.params['channel'] = old_channels
-            err_msg = ""
-
-        if not err_msg:
-
-            query_analysis.set_limit(page_size, page_num)
-            query_analysis.query_sql_handle()
-
-            # 设置排序
-            sort_type = _g('sort_type', '')
-            sort_fields_index = int(_g('sort_index', '') or -1)
-            if sort_fields_index >= 0 and len(fields) >= sort_fields_index:
-                sort_field_name = fields[sort_fields_index]
-                sort_key = query_analysis.query.field_config.get(
-                        sort_field_name, {}).get('name', '')
-                if sort_key and sort_type:
-                    query_analysis.set_order(sort_key, sort_type)
-
-            count_sql = query_analysis.get_count_sql()
-            query_sql = query_analysis.get_query_sql()
-
-            # 知道结果的数量情况下,添加_分页,不执行count设置分页
-            if query_analysis.query.field_config.get(u'_分页', {}).get('default_value', '') == '0':
-                total_record = page_size
-
-            # 默认不打印sql
-            if settings.DEBUG or request.REQUEST.get('_sql', ''):
-                print(query_sql)
-
-            # print count_sql
-
-            cache_time = int(query_analysis.query.cache_validate)
-            count_sql_key = md5('%s_%s' % (count_sql, server_id))
-            cursor = conn.cursor()
-            if not total_record:
-                total_record, result_cache_time = cache_func(
-                        count_sql_key, get_query_result_cout, (conn, count_sql), timeout=cache_time)
-
-            if total_record:
-                query_sql_key = md5('%s_%s' % (query_sql, server_id))
-                total_page = total_record / page_size
-                if total_record % page_size != 0:
-                    total_page += 1
-                list_data, result_cache_time = cache_func(
-                        query_sql_key, get_query_result, (conn, query_sql), timeout=cache_time)
-                list_data, result_cache_time = cache_func('display_%s' % query_sql_key, query_display_process, (
-                        query_analysis, list_data, page_num, page_size), timeout=cache_time)
-                tfoot_sql = query_analysis.get_tfoot_sql()
-
-                if tfoot_sql:
-                    tfoot_sql_key = md5('%s_%s' % (tfoot_sql, server_id))
-                    tfoot_data, result_cache_time = cache_func(
-                            'tfoot_%s' % tfoot_sql_key, get_query_result, (conn, tfoot_sql), timeout=cache_time)
+            if tfoot_sql:
+                tfoot_sql_key = md5('%s_%s' % (tfoot_sql, server_id))
+                tfoot_data, result_cache_time = cache_func(
+                        'tfoot_%s' % tfoot_sql_key, get_query_result, (conn, tfoot_sql), timeout=cache_time)
     except Exception as e:
         err_msg = trace_msg()
         err_msg = '%s\nthe_sql:%s' % (err_msg, query_sql)
-        print(err_msg)
-    fields = query_analysis.query.selects
+        logging.error(err_msg)
+    fields = query_compiler.query.selects
     if list_data_handle and callable(list_data_handle):
         list_data = list_data_handle(list_data)
     if built_in:  # 导出
@@ -515,7 +360,7 @@ def query_do(request, query_analysis, built_in=False, list_data_handle=None):
 
     exec_time = '%.3f' % (time.time() - now)
     response = render(request,
-            'analysis/return/%s.html' % template_name, locals())
+                      'analysis/return/%s.html' % template_name, locals())
     response['Order-Record-Count'] = total_record
     response['Page-Num'] = page_num
     response['Page-Size'] = page_size
@@ -525,8 +370,8 @@ def query_do(request, query_analysis, built_in=False, list_data_handle=None):
 
 @Route('analysis/query/clear/cache$')
 def query_clear_cache(request):
-    '''清除查询缓存
-    '''
+    """清除查询缓存
+    """
     clear_cache(CACHE_TYPE.LOG_CACHE)
     return HttpResponse('成功!')
     # return render(request,'feedback.html')
@@ -549,13 +394,13 @@ ip_db = None
 from framework.utils.ip import ip_transform
 
 
-def query_display_process(query_analysis, list_data, page_num, page_size):
-    '''值定义处理
-    '''
-    fields = query_analysis.query.selects  # 查询的表头
+def query_display_process(query_compiler, list_data, page_num, page_size):
+    """值定义处理
+    """
+    fields = query_compiler.query.selects  # 查询的表头
     field_configs = []
     for field_name in fields:
-        field_config = query_analysis.query.field_config.get(field_name, {})
+        field_config = query_compiler.query.field_config.get(field_name, {})
         field_config['field_name'] = field_name
         dict_key = field_config.get('dict', '')
         value_defs = DictDefine.get_dict_for_key(dict_key, reverse=False)
@@ -590,8 +435,8 @@ def query_display_process(query_analysis, list_data, page_num, page_size):
 
 
 def display_format(field_config, value):
-    '''转格式
-    '''
+    """转格式
+    """
     field_name = field_config.get('field_name', '')
     def_values = field_config['value_defs']
 
