@@ -19,6 +19,7 @@ from framework.views import is_notauth, is_notcheck
 from framework.utils import md5
 from .models.user import User
 from django.contrib.auth import SESSION_KEY
+
 # ==========================================
 
 # 日志记录
@@ -41,7 +42,8 @@ class AuthMiddleware(BaseMiddleware):
         pass
 
     def is_pass(self, view_func):
-        return view_func.__module__ == 'django.views.static' or view_func.__module__ == 'framework.static' or view_func.__module__.find('debug_toolbar')>=0
+        return view_func.__module__ == 'django.views.static' or view_func.__module__ == 'framework.static' or view_func.__module__.find(
+            'debug_toolbar') >= 0
 
     def process_view(self, request, view_func, view_args, view_kwargs):
         """静态文件及有"notauth" 属性view_func 免认证
@@ -58,7 +60,7 @@ class AuthMiddleware(BaseMiddleware):
                 check_view_func = getattr(check_view_func, view_kwargs['path'], None) or check_view_func
 
         # 不需要登陆
-        if is_notauth(check_view_func) or self.is_pass(view_func) :  # 不需处理的函数不管
+        if is_notauth(check_view_func) or self.is_pass(view_func):  # 不需处理的函数不管
             is_allow = True
 
             if ((request.path_info.find('/login') == 0 or request.path_info.find(
@@ -77,28 +79,8 @@ class AuthMiddleware(BaseMiddleware):
                 login_url = settings.LOGIN_URL
                 return HttpResponseRedirect('%s?from_url=%s' % (login_url, request.get_full_path()))
 
-            user_menus = request.user.resource.menu.using('read')
-
-            class UserAllowMenu(dict):
-                def __init__(self, user):
-                    self.user = user
-                    super(UserAllowMenu, self).__init__()
-
-                def __getattr__(self, name):
-                    try:
-                        menu_obj = self.get(name, None)
-                        if not menu_obj and self.user.is_root:
-                            return True
-                        return menu_obj
-                    except KeyError:
-                        raise AttributeError(name)
-
-            _user_menu_map = UserAllowMenu(request.user)
-            for m in user_menus.all():
-                menu_name = m.name
-                _user_menu_map[menu_name] = m
-            request.allow_menu = _user_menu_map
-            request.allow = _user_menu_map
+            the_user.make_allow_map()
+            request.allow = request.allow_menu = the_user.allow_menu
             is_allow = self.check_url_permsssion(request)
 
             if is_notcheck(check_view_func):
@@ -123,7 +105,7 @@ class AuthMiddleware(BaseMiddleware):
         params = request.REQUEST
 
         # 管理员的菜单里查询匹配项目
-        for k, menu in request.allow_menu.items():
+        for menu in request.user.menu_map.get(url_path, []):
             if url_path == menu.url_path and menu.is_match_url_parmas(params):
                 match_menu = menu
                 is_allow = True
