@@ -10,30 +10,26 @@ from __future__ import absolute_import, unicode_literals
 
 import os
 
-from celery import Celery, Task
-from celery.result import AsyncResult
+from celery import Celery
 
 # set the default Django settings module for the 'celery' program.
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'settings')
 
 app = Celery('celery_app')
 
-
 # Using a string here means the worker doesn't have to serialize
 # the configuration object to child processes.
 # - namespace='CELERY' means all celery-related configuration keys
 #   should have a `CELERY_` prefix.
 app.config_from_object('django.conf:settings', namespace='CELERY')
 
-from django.conf import settings
-#settings.DEBUG = False
-# Load task modules from all registered Django app configs.
 app.autodiscover_tasks()
 
 
-@app.task(bind=True)
+@app.task(bind=True, ignore_result=True)
 def debug_task(self):
     print('Request: {0!r}'.format(self.request))
+    return self.request.id
 
 
 # 设置任务路由 启动 celery 进程 用 -Q myadmin
