@@ -10,17 +10,18 @@ import warnings
 
 import coreapi
 import coreschema
+import timezone_field
 from django.db import models
 from django.db.models import Q
 from django.utils.translation import gettext_lazy as _
-from django_filters.rest_framework import DjangoFilterBackend
+from django_filters.rest_framework import DjangoFilterBackend, filterset, filters
 from rest_framework.filters import OrderingFilter as _OrderingFilter
 from rest_framework.request import Request
 
 from .response import RspError
 from .serializer import s
 from .utils.myenum import Enum
-
+from .models import BaseModel
 
 class OrderingFilter(_OrderingFilter):
     ordering_description = _('排序字段 -xxx 为倒序 如:-id')
@@ -106,18 +107,23 @@ class BooleanFilterQ(FilterQ):
             return False
         return True
 
+class OperatorEnum(Enum):
+    @classmethod
+    def get_filter_q_obj(cls, operator_type):
+        return cls(operator_type).other
 
-class EqualOperator(Enum):
+
+class EqualOperator(OperatorEnum):
     Equal = 'exact', _('等于'), FilterQ()
     NotEqual = 'not_exact', _('不等于'), FilterQ(negated=True)
 
 
-class NullOperator(Enum):
+class NullOperator(OperatorEnum):
     NotNull = 'not_null', _('有值'), BooleanFilterQ(lookup_expr='isnull', negated=True)
     IsNull = 'is_null', _('没值'), BooleanFilterQ(lookup_expr='isnull', )
 
 
-class InOperator(Enum):
+class InOperator(OperatorEnum):
     SingleIn = 'single_in', _('单选'), InFilterQ()
     In = 'in', _('多选'), InFilterQ()
     NotIn = 'not_in', _('反选'), InFilterQ(negated=True)
@@ -166,7 +172,7 @@ class NumberOperator(EqualOperator, InOperator):
     Between = 'range', _('区间'), RangeFilterQ()
 
 
-class DateTimeOperator(Enum):
+class DateTimeOperator(OperatorEnum):
     """
     ## 时间类型属性筛选
 
@@ -200,6 +206,11 @@ class ConditionTypeEnum(Enum):
     DateTime = 'date', _('日期时间'), DateTimeOperator
     Choice = 'choice', _('多选'), ChoiceOperator
 
+
+    @classmethod
+    def get_operator_type(cls, condition_type):
+        return cls(condition_type).other
+
     @classmethod
     def get_schema(cls):
         schema_map = {}
@@ -212,6 +223,7 @@ class MyFilterSerializer(s.Serializer):
     pass
 
 
+
 class MyFilterBackend(DjangoFilterBackend):
     """
     # 准确等值
@@ -222,12 +234,13 @@ class MyFilterBackend(DjangoFilterBackend):
     DELIMITER = FilterQ.DELIMITER
 
     @staticmethod
-    def guess_condition_type(operator) -> Enum:
+    def guess_condition_filter_q_obj(operator) -> FilterQ:
 
         for condition_type, _ in ConditionTypeEnum.member_list():
-            operator_type = condition_type.other(operator)
+            operator_enum = ConditionTypeEnum.get_operator_type(condition_type)
+            operator_type = operator_enum(operator)
             if operator_type:
-                return operator_type
+                return operator_enum.get_filter_q_obj(operator)
         return None
 
     def get_filter_q(self, request, filterset_fields):
@@ -239,10 +252,9 @@ class MyFilterBackend(DjangoFilterBackend):
                 name, operator = key_array[:2]
                 if name not in filterset_fields:
                     raise RspError(_('%s 未被允许的筛选字段' % name))
-                condition_operator_type = self.guess_condition_type(operator)
-                if condition_operator_type is None:
+                filter_q_obj: FilterQ = self.guess_condition_filter_q_obj(operator)
+                if filter_q_obj is None:
                     raise RspError(_('%s 未定义操作类型' % operator))
-                filter_q_obj: FilterQ = condition_operator_type.other
 
                 value_list = request.query_params.getlist(key)
 
@@ -309,24 +321,30 @@ class MyFilterBackend(DjangoFilterBackend):
         except Exception:
             queryset = view.model.objects.filter(id=-1)
             warnings.warn(
-                    "{} is not compatible with schema generation".format(view.__class__)
+                    "%s is not compatible with schema generation" % view.__class__
             )
 
         filterset_class = self.get_filterset_class(view, queryset)
         model_class = filterset_class.Meta.model
-        model_fields_map = model_class.get_fields_map()
+
         schema_fields = []
         if filterset_class:
-            for field_name, field in filterset_class.base_filters.items():
-                model_field = model_fields_map.get(field_name, models.CharField())
-                schema_fields.append(self.generate_coreschema_from_model_field(field_name, model_field))
-            schema_fields.append(coreapi.Field(
-                    name='fields',
-                    required=False,
-                    location='query',
-                    schema=coreschema.String(
-                            description='需要返回的字段","号隔开:入 fields=id,name,alias,status'
-                    )
-            ))
-            return schema_fields
+            if issubclass(model_class,BaseModel):
+                model_fields_map = model_class.get_fields_map()
+
+                for field_name, field in filterset_class.base_filters.items():
+                    model_field = model_fields_map.get(field_name, models.CharField())
+                    schema_fields.append(self.generate_coreschema_from_model_field(field_name, model_field))
+                schema_fields.append(coreapi.Field(
+                        name='fields',
+                        required=False,
+                        location='query',
+                        schema=coreschema.String(
+                                description='需要返回的字段","号隔开:入 fields=id,name,alias,status'
+                        )
+                ))
+                return schema_fields
         return []
+
+
+filterset.FILTER_FOR_DBFIELD_DEFAULTS[timezone_field.TimeZoneField] = {'filter_class': filters.CharFilter}
